# Quickstart

ETLPlus can be used from the command line or imported as a Python package.

Get up and running in under a minute.

## Command line

```{include} ../../../README.md
:start-after: <!-- docs:getting-started-quickstart-cli:start -->
:end-before: <!-- docs:getting-started-quickstart-cli:end -->
```

## Python API

```{include} ../../../README.md
:start-after: <!-- docs:getting-started-quickstart-python:start -->
:end-before: <!-- docs:getting-started-quickstart-python:end -->
```

## Where to go next

- See the {doc}`examples guide <../guides/examples>` for runnable sample files.
- See the {doc}`pipeline authoring guide <../guides/pipeline-authoring>` for
  config-driven ETL jobs.
- See the {doc}`API reference <../api/index>` for module-level reference
  material generated from docstrings.
